# Table of Contents #

- [Overview](#overview)
    - [Table Structure](#table-structure)
    - [Attributes](#attributes)
        * [Gender](#gender)
- [Statistics](#statistics)
- [Clothing](#clothing)
- [Powers](#powers)
- [Defining Characters](#defining-characters)

# Overview #

Characters are the heart of any game written in the Scarlet engine, and one
of the most complex parts. They are used to resolve game text. They
have statistics, powers and equipment that come into play in combat
(and possibly elsewhere) . They also have a (possibly
customizable) gender, a custom name, perhaps even customizable physical
attributes.

## Table Structure ##

To model all of this, a character is an ordered table with the following keys:

* name: The internal name of the character. This is a unique identifier used
        internally by the Scarlet engine.
* printedname: The name to display to players for this character.
* combatname: The name to use for this character in combat
* concisename: The name to use for this character on the combat board (next to
the combat log) under the concise view. This will typically be one or two letters.


* statistics: An ordered table of [statistics](#statistics) keyed on name.

* powers: An ordered table of powers that this character has, keyed on power
    name.  See [Powers](combat/powers.md) for details.

* choice: The first choice the character makes each combat round. This
    is a combat page, and will typically describe the basic combat actions
    (attack, power) the character can execute, but can also include more
    elaborate things like a status that should be automatically inflicted at the
    start of combat.

* clothing: An ordered table of clothing keyed on slots (strings like "upper"
    or "lower" representing where on the body the clothing goes).
    For more details about clothing, see [Clothing](#clothing).

* ai: A custom AI function that may be used by this character. If `nil`, then
    this value is ignored when choosing the AI to use for a character in battle.
    See [AI](../combat/ai.md) for details.

* statuses: A list of the statuses inflicting the character, in the order they
    were inflicted. Each status contains two keys:
        - status: The actual [status](#combat.md#status) being inflicted.
        - duration: How many more rounds the status will linger

* pc: `true` if the character is fully defined and controlled by the player,
    `false` (or `nil`) otherwise

* choicecounts: An ordered table that maps combat action names
   (i.e. `attack` `power`) to a table containing two keys:
        * `count` - The number of times the action can be executed
        * `page` - A combat page for this action

* modifiers: A table of named modifiers that have been activated by this
character. This table is necessary to allow us to remove expired
modifiers (i.e. remove the modifiers added by a status when the status
expires). Note that this is *not* the source of modifiers used when applying
them to combat primitives, `combatstate.modifiers` handles that.

* attributes: A table of game-specific attributes, like height or gender.
See [attributes](#attributes) for more details.

* bummarks: A list of strings describing the state of the player's bottom.

* huge: An optional field that should be true if and only if the character is
considered "huge" (i.e. too big for an adult to put over their knee, huge
characters may include an enemy who can grow ten feet tall, or a giant clay
teddy bear). This should be used when defining spanking descriptions to make
sure the description makes sense when dealing with huge opponents.

### Attributes ###

In addition to the properties above, characters may also have custom, game
specific attributes. Attributes are properties of a character that are
used to resolve text. Some sample attributes may include:

* gender: The gender of a character. See [Gender](#gender) section for more details.
* hairstyle: The character's hairstyle.
* haircolor: The character's hair color.
* height: The character's height.
* skincolor: The character's skin color.
* bodytype: The character's body type  (i.e. thin, fat, athletic)

Attributes are string values. They may have any value, and may have any name
(so long as they don't clash with the keys defined above), since they are used
purely to resolve dynamic text.

Below is a sample attribute. Note that these attributes do not need to
be used in a Scarlet game, nor do they need to necessarily fit the structure
outlined below. Only the `story` functions (i.e. `story/templatefunctions`,
`story/predicates`, `story/operations` need to know anything about
attributes.

#### Gender ####

A character's gender can be one of three values: `male`, `female`, or `unknown`.
If the character's gender is `unknown`, then the gender must be selected
(either automatically or by the player) before the character can be used.

# Statistics #

The statistics are the heart of a character: numbers that represent the
character's raw power, and/or skill at various activities.

[Combat](./combat.md) in Scarlet is built under the assumption that there are
five statistics:

* strength: A character's raw physical strength, determines how
        effective they are in a grapple, and fighting in melee range.
* speed: A character's raw speed, and determines how effective they are in
        melee, and at a distance.
* power: A character's superpower. Power controls the effectiveness of many
        powers.
* maxenergy: The maximum amount of energy the character has available. Energy
        represents how much damage your character can take before collapsing.
        It is __also__ used to fuel powers.
* energy: The character's current energy level.

# Clothing #

The clothing currently worn by the character. Clothing is equipped into
equip slots, and may take up multiple slots. Equip slots are only identified
by name. Scarlet makes no assumptions about what the equip slots are.

Every article of clothing is a table with the following properties:

* name: The name of the clothing
* description: A brief description of the clothing.
* slots: The list of equipment slots that this clothing occupies.
* risque: How revealing the outfit is. A higher risque means the outfit shows
    more skin. For lower clothing, a risque of 5 or more means that some of
    the wearer's bottom is exposed
* type: A string providing a type for the clothing (i.e. "skirt", "pants")
* selectable: An optional boolean that indicates whether the player can equip
    this to the PC directly.

Of course, clothing may have additional fields used by a specific game. The
engine itself does nothing with clothing except handle equipping and
unequipping them.

# Powers #

Powers are special abilities that characters possess. These are typically
used in combat. They may do damage, inflict statuses, even bend or break the
rules of combat.

As such, all powers are combat pages that should eventually resolve into
one or more atomic actions.

# Defining Characters #

Characters are defined in `data/characters.lua` (For games with a lot of
characters, it is recommended that the characters are broken out into modules,
which are imported by `data/characters.lua`).
