#!/bin/bash

# A shell script that builds the LOVE executables for Windows, Linux and Mac OS X
# It takes a single argument: A string containing the version number.

# It places under distribution a LOVE application for each of Windows, Mac OS X, and Linux.

# This script assumes there is a distributions directory already with children
# `windows`, `mac` and linux. The distributions/windows should have all the
# dlls needed for the executable (basically everything except love.exe from
# the zipped bundle you can download off of love2d.org).

# It also assumes the existence of a executables/love.exe and
# executables/love.app in the game's root directory. These are *NOT* included in
# source control, they will need to be downloaded separately.

set -e
set -x
SCARLET_MOON=scarlet-moon

VERSION="$1"

rm -f build/*
# Build windows executable.
zip -9 -r build/$SCARLET_MOON.love . -x build/\* distributions/\* executables/\* tests/\* .git/\* .* *.md

# Clean the previous build
rm -f distributions/windows/*.exe
rm -f distributions/windows/*.love
rm -f distributions/windows-64/*.exe
rm -f distributions/windows-64/*.love
rm -f -r distributions/mac/*.app
rm -f distributions/mac/*.love
rm -f distributions/linux/*.love
rm -f distributions/*.bundle

mkdir -p distributions

# Zip up the source, *and* create a git bundle.
zip -9 -r distributions/$SCARLET_MOON-$1-source.zip . -x build/**\* executables/**\* distributions/**\* .git/**\* .gitignore .gitmodules lump/.git/**\* lump/.gitignore lump/.gitmodules f-string/.git/**\* f-string/.gitignore f-string/.gitmodules SUIT/.git/**\* SUIT/.gitignore SUIT/.gitmodules
git bundle create distributions/source.bundle --all
zip distributions/source.bundle.zip distributions/source.bundle
rm -f distributions/source.bundle
git tag $VERSION

# Build windows executables, 32.
mkdir -p distributions/windows
cat executables/love-11.2.0-win32/love.exe build/$SCARLET_MOON.love > distributions/windows/$SCARLET_MOON.exe
cp executables/love-11.2.0-win32/*.dll distributions/windows/.
cp executables/love-11.2.0-win32/*.txt distributions/windows/.
cp executables/love-11.2.0-win32/*.ico distributions/windows/.
cp ui/OFL.txt distributions/windows/.
cp LICENSE distributions/windows/.
cd distributions/windows
zip -9 -r ../$SCARLET_MOON-$VERSION-windows.zip .
cd -

#mkdir -p distributions/windows
#cat executables/love-11.2.0-win64/love.exe build/$SCARLET_MOON.love > distributions/windows-64/$SCARLET_MOON.exe
#cp ui/OFL.txt distributions/windows-64/.
#cp LICENSE distributions/windows-64/.
#cd distributions/windows-64
#zip -9 -r ../$SCARLET_MOON-$VERSION-windows-64.zip .
#cd -

# Build console version for Windows
rm -rf distributions/console-windows/
mkdir -p distributions/console-windows/
mkdir -p distributions/console-windows/scarlet-moon-lua
mkdir -p distributions/console-windows/executables
cp -r executables/console/windows/lua52 distributions/console-windows/executables
find . | grep ".lua\|.story" | grep -v executables | grep -v SUIT | grep -v distributions | xargs -I _ cp -r --parent _ distributions/console-windows/scarlet-moon-lua/.
cp scripts/ScarletMoon.bat distributions/console-windows/.
cp LICENSE distributions/console-windows/.
cp ui/OFL.txt distributions/console-windows/.
mkdir -p distributions/console-windows/scarlet-moon-lua/saves/
cd distributions/console-windows/
zip -9 -r ../$SCARLET_MOON-$VERSION-windows-console.zip .
cd -

# Build Mac OS X executables.
mkdir -p distributions/mac
cp -r executables/love.app distributions/mac/$SCARLET_MOON.app
cp build/$SCARLET_MOON.love distributions/mac/$SCARLET_MOON.app/Contents/Resources/.
cp ui/OFL.txt distributions/mac/.
cp LICENSE distributions/mac/.
cd distributions/mac
zip -9 -y -r ../$SCARLET_MOON-$VERSION-mac.zip .
cd -

# Build Linux executable.
mkdir -p distributions/linux
cp build/$SCARLET_MOON.love distributions/linux/.
cp ui/OFL.txt distributions/linux/.
cp LICENSE distributions/linux/.
cd distributions/linux
zip -9 -r ../$SCARLET_MOON-$VERSION-linux.zip .
cd -

# Build console version for Linux
rm -rf distributions/console-linux/
mkdir -p distributions/console-linux/
mkdir -p distributions/console-linux/scarlet-moon-lua
mkdir -p distributions/console-linux/executables
find . | grep ".lua\|.story" | grep -v executables | grep -v SUIT | grep -v distributions | xargs -I _ cp -r --parent _ distributions/console-linux/scarlet-moon-lua/.
cp scarletmoon.sh distributions/console-linux/scarlet-moon-lua/.
cp LICENSE distributions/console-linux/.
cp ui/OFL.txt distributions/console-linux/.
mkdir -p distributions/console-linux/scarlet-moon-lua/saves/
cd distributions/console-linux/
zip -9 -r ../$SCARLET_MOON-$VERSION-linux-console.zip .
cd -

# Build console version for Mac
rm -rf distributions/console-mac/
mkdir -p distributions/console-mac/
mkdir -p distributions/console-mac/scarlet-moon-lua
mkdir -p distributions/console-mac/executables
find . | grep ".lua\|.story" | grep -v executables | grep -v SUIT | grep -v distributions | xargs -I _ cp -r --parent _ distributions/console-mac/scarlet-moon-lua/.
cp scripts/scarletmoon-mac.sh distributions/console-mac/.
cp LICENSE distributions/console-mac/.
cp ui/OFL.txt distributions/console-mac/.
cp -r executables/console/mac/lua52 distributions/console-mac/executables
mkdir -p distributions/console-mac/scarlet-moon-lua/saves/
cd distributions/console-mac/
zip -9 -r ../$SCARLET_MOON-$VERSION-mac-console.zip .
cd -
