# Table of Contents #

- [Overview](#overview)
- [Structure](#structure)

# Overview #

Here is where we define the table of options. We describe how they are
structured, how they work, as well as future thoughts for making them more
extendable.

Options are meant to provide users some gameplay customizability. They may
control such things as how intelligent the AI is, how strong enemies are,
and son. Note that these are only gameplay options. They do not (currently)
allow customization of visual things (such as how fast text is displayed, or
the color of the game windows).

To help illustrate the concepts in this document, we will assume the following
options, with the following values:

```
AI : Dumb, Average, Smart
Villain Stats: 50% 75% 100%
```

# Structure #

There are two options tables. The first table is `configuration.options`, and
this defines the meaning of each value. `configuration.options` is an ordered
table that maps option names to a list of tables. Each table in the list has
three entries: `name`,
`apply`, `remove`. `name` is the name of the option value. `apply` is an
operation that takes a `gamestate` and
modifies it when the associated option takes effect. `remove` is an operation
that takes a `gamestate` and removes the effect. For example, for our above
example, `configuration.options` may look like:

```lua
{
    _keys={"AI", "Villain Stats"},
    AI={
        {
            name="Dumb",
            apply=function(gamestate)
                gamestate.options.ai = dumb
            end,
            remove=function() end
        },
        {
            name="Average",
            apply=function(gamestate)
                gamestate.options.ai = average
            end,
            remove=function() end
        },
        {
            name="Smart",
            apply=function(gamestate)
                gamestate.options.ai = smart
            end,
            remove=function() end
        },
    },
    "Villain Stats"={
        {
            name="50%",
            apply=modifyVillainStats(.5),
            remove=resetVillainStats
        },
        {
            name="75%",
            apply=modifyVillainStats(.75),
            remove=resetVillainStats,
        },
        {
            name="100%",
            apply=function() end,
            remove=function() end
        }
    }
}
```

This table is defined in `data/options.lua`.

`modifyVillainStats` is a function that takes a decimal and returns
a function that iterates over every villain in the game and multiplies their
primary statistics by the passed in decimal. `resetVillainStats` is an operation
that takes a `gamestate` and resets each villain's stats to their original
value. `dumb`, `average`, and `smart` are each functions that for selecting the
actions to be performed by an enemy. For details see the [AI](./ai.md) document.

This table also has an optional key `startindex`. This is the index of the 
default option. `startindex` defaults to 1.

The second is `gamestate.options`, which tracks the current settings for each
option. It maps option names to the name of the currently selected option.

```lua
{
    AI="Average",
    ["Villain Stats"]="100%"
}
```

Then, when we need to know the current settings (i.e. we open the `Options`
screen), we can iterate over the options in `gamestate.options` and extract
the name of each setting.

Furthermore, when we change a setting, we invoke
`gamestate.configuration.options[changed].remove(gamestate)`, set
`gamestate.options[changed] = new` and invoke
`gamestate.configuration.options[new].apply(gamestate)`.
